@@ -4,7 +4,7 @@
 '''
 
 from .omas_utils import *
-from .omas_core import ODS, codeparams_xml_save, codeparams_xml_load, dynamic_ODS
+from .omas_core import ODS, codeparams_xml_save, codeparams_xml_load, dynamic_ODS, omas_environment
 from .omas_utils import _extra_structures
 
 
@@ -324,12 +324,7 @@ def save_omas_imas(ods, user=None, machine=None, pulse=None, run=None, occurrenc
     if imas_version is not None and 'dataset_description.imas_version' not in ods:
         ods['dataset_description.imas_version'] = ods.imas_version
 
-    if user is not None and machine is not None:
-        printd(
-            'Saving to IMAS (user:%s machine:%s pulse:%d run:%d, imas_version:%s)' % (user, machine, pulse, run, imas_version), topic='imas'
-        )
-    elif user is None and machine is None:
-        printd('Saving to IMAS (pulse:%d run:%d, DB:%s)' % (pulse, run, os.environ.get('MDSPLUS_TREE_BASE_0', '???')[:-2]), topic='imas')
+    printd('Saving to IMAS (user:%s machine:%s pulse:%d run:%d, imas_version:%s)' % (user, machine, pulse, run, imas_version), topic='imas')
 
     # ensure requirements for writing data to IMAS are satisfied
     ods.satisfy_imas_requirements()
@@ -484,9 +479,6 @@ def load_omas_imas(
     """
     Load OMAS data from IMAS
 
-    NOTE: Either specify both or none of `user` and `machine`
-    If none of them are specified then use `imasdb` command to set the `MDSPLUS_TREE_BASE_?` environmental variables
-
     :param user: IMAS username
 
     :param machine: IMAS machine
@@ -560,27 +552,37 @@ def load_omas_imas(
             )
             # build omas data structure
             ods = ODS(imas_version=imas_version, consistency_check=False)
-            for k, path in enumerate(fetch_paths):
-                if path[-1].endswith('_error_upper') or path[-1].endswith('_error_lower') or path[-1].endswith('_error_index'):
-                    continue
-                if verbose and (k % int(numpy.ceil(len(fetch_paths) / 10)) == 0 or k == len(fetch_paths) - 1):
-                    print('Loading {0:3.1f}%'.format(100 * float(k) / (len(fetch_paths) - 1)))
-                # get data from IDS
-                data = imas_get(ids, path, None)
-                # continue for empty data
-                if data is None:
-                    continue
-                # add uncertainty
-                if not skip_uncertainties and l2i(path[:-1] + [path[-1] + '_error_upper']) in joined_fetch_paths:
-                    stdata = imas_get(ids, path[:-1] + [path[-1] + '_error_upper'], None)
-                    if stdata is not None:
-                        try:
-                            data = uarray(data, stdata)
-                        except uncertainties.core.NegativeStdDev as _excp:
-                            printe('Error loading uncertainty for %s: %s' % (l2i(path), repr(_excp)))
-                # assign data to ODS
-                # NOTE: here we can use setraw since IMAS data is by definition compliant with IMAS
-                ods.setraw(path, data)
+            if verbose and tqdm is not None:
+                progress_fetch_paths = tqdm.tqdm(fetch_paths, file=sys.stdout)
+            else:
+                progress_fetch_paths = fetch_paths
+            with omas_environment(ods, dynamic_path_creation='dynamic_array_structures'):
+                for k, path in enumerate(progress_fetch_paths):
+                    # print progress
+                    if verbose:
+                        if tqdm is not None:
+                            progress_fetch_paths.set_description(joined_fetch_paths[k])
+                        elif k % int(numpy.ceil(len(fetch_paths) / 10)) == 0 or k == len(fetch_paths) - 1:
+                            print('Loading {0:3.1f}%'.format(100 * float(k) / (len(fetch_paths) - 1)))
+                    # uncertain data is loaded as part of the nominal value of the data
+                    if path[-1].endswith('_error_upper') or path[-1].endswith('_error_lower') or path[-1].endswith('_error_index'):
+                        continue
+                    # get data from IDS
+                    data = imas_get(ids, path, None)
+                    # continue for empty data
+                    if data is None:
+                        continue
+                    # add uncertainty
+                    if not skip_uncertainties and l2i(path[:-1] + [path[-1] + '_error_upper']) in joined_fetch_paths:
+                        stdata = imas_get(ids, path[:-1] + [path[-1] + '_error_upper'], None)
+                        if stdata is not None:
+                            try:
+                                data = uarray(data, stdata)
+                            except uncertainties.core.NegativeStdDev as _excp:
+                                printe('Error loading uncertainty for %s: %s' % (l2i(path), repr(_excp)))
+                    # assign data to ODS
+                    # NOTE: here we can use setraw since IMAS data is by definition compliant with IMAS
+                    ods.setraw(path, data)
 
         finally:
             # close connection to IMAS database
@@ -600,10 +602,6 @@ def load_omas_imas(
         if 'ids_properties' in ods[ds]:
             ods[ds]['ids_properties.occurrence'] = occurrence.get(ds, 0)
 
-    # must manually call set_child_locations since
-    # we used the ODS.setraw that does not do that for us
-    ods.set_child_locations()
-
     try:
         ods.consistency_check = consistency_check
     except LookupError as _excp:
@@ -614,9 +612,8 @@ def load_omas_imas(
 
 class dynamic_omas_imas(dynamic_ODS):
     """
-    Class that provides dynamic data loading from NC file
-    This class is not to be used by itself, but via the
-    ODS.open() method.
+    Class that provides dynamic data loading from IMAS
+    This class is not to be used by itself, but via the ODS.open() method.
     """
 
     def __init__(self, user=os.environ.get('USER', 'dummy_user'), machine=None, pulse=None, run=0, occurrence={}, verbose=True):
@@ -943,7 +940,7 @@ def through_omas_imas(ods, method=['function', 'class_method'][1]):
     machine = 'ITER'
     pulse = 1
     run = 0
-
+    ods = copy.deepcopy(ods)  # make a copy to make sure save does not alter entering ODS
     if method == 'function':
         paths = save_omas_imas(ods, user=user, machine=machine, pulse=pulse, run=run, new=True)
         ods1 = load_omas_imas(user=user, machine=machine, pulse=pulse, run=run, paths=paths)
@@ -951,3 +948,74 @@ def through_omas_imas(ods, method=['function', 'class_method'][1]):
         paths = ods.save('imas', user=user, machine=machine, pulse=pulse, run=run, new=True)
         ods1 = ODS().load('imas', user=user, machine=machine, pulse=pulse, run=run, paths=paths)
     return ods1
+
+
+# List IDS fields that have to be present to add datasets in the ITER scenario database
+# as defined here: from https://confluence.iter.org/x/kQqOE
+iter_scenario_requirements = [
+    'equilibrium.time_slice.:.global_quantities.ip',
+    'equilibrium.time_slice.:.profiles_2d.:.phi',
+    'equilibrium.time_slice.:.profiles_2d.:.psi',
+    'equilibrium.time_slice.:.profiles_2d.:.r',
+    'equilibrium.time_slice.:.profiles_2d.:.z',
+    'equilibrium.vacuum_toroidal_field.r0',
+    'equilibrium.vacuum_toroidal_field.b0',
+    'core_profiles.global_quantities.beta_pol',
+    'core_profiles.global_quantities.beta_tor_norm',
+    'core_profiles.global_quantities.current_bootstrap',
+    'core_profiles.global_quantities.current_non_inductive',
+    'core_profiles.global_quantities.energy_diamagnetic',
+    'core_profiles.global_quantities.ip',
+    'core_profiles.global_quantities.v_loop',
+    'core_profiles.profiles_1d.:.e_field.radial',
+    'core_profiles.profiles_1d.:.electrons.density',
+    'core_profiles.profiles_1d.:.electrons.pressure',
+    'core_profiles.profiles_1d.:.electrons.pressure_fast_parallel',
+    'core_profiles.profiles_1d.:.electrons.pressure_fast_perpendicular',
+    'core_profiles.profiles_1d.:.electrons.pressure_thermal',
+    'core_profiles.profiles_1d.:.electrons.temperature',
+    'core_profiles.profiles_1d.:.grid.rho_tor',
+    'core_profiles.profiles_1d.:.grid.rho_tor_norm',
+    'core_profiles.profiles_1d.:.grid.psi',
+    'core_profiles.profiles_1d.:.grid.volume',
+    'core_profiles.profiles_1d.:.ion.:.density',
+    'core_profiles.profiles_1d.:.ion.:.element.:.a',
+    'core_profiles.profiles_1d.:.ion.:.element.:.z_n',
+    'core_profiles.profiles_1d.:.ion.:.pressure',
+    'core_profiles.profiles_1d.:.ion.:.pressure_fast_parallel',
+    'core_profiles.profiles_1d.:.ion.:.pressure_fast_perpendicular',
+    'core_profiles.profiles_1d.:.ion.:.pressure_thermal',
+    'core_profiles.profiles_1d.:.ion.:.temperature',
+    'core_profiles.profiles_1d.:.ion.:.velocity.diamagnetic',
+    'core_profiles.profiles_1d.:.ion.:.velocity.poloidal',
+    'core_profiles.profiles_1d.:.ion.:.velocity.toroidal',
+    'core_profiles.profiles_1d.:.j_bootstrap',
+    'core_profiles.profiles_1d.:.j_non_inductive',
+    'core_profiles.profiles_1d.:.j_ohmic',
+    'core_profiles.profiles_1d.:.j_total',
+    'core_profiles.profiles_1d.:.magnetic_shear',
+    'core_profiles.profiles_1d.:.pressure_ion_total',
+    'core_profiles.profiles_1d.:.pressure_parallel',
+    'core_profiles.profiles_1d.:.pressure_perpendicular',
+    'core_profiles.profiles_1d.:.pressure_thermal',
+    'core_profiles.profiles_1d.:.q',
+    'core_profiles.profiles_1d.:.t_i_average',
+    'core_profiles.profiles_1d.:.zeff',
+    'summary.global_quantities.b0.value',
+    'summary.global_quantities.r0.value',
+    'summary.global_quantities.beta_pol.value',
+    'summary.global_quantities.beta_tor_norm.value',
+    'summary.global_quantities.current_bootstrap.value',
+    'summary.global_quantities.current_non_inductive.value',
+    'summary.global_quantities.current_ohm.value',
+    'summary.global_quantities.energy_diamagnetic.value',
+    'summary.global_quantities.energy_thermal.value',
+    'summary.global_quantities.energy_total.value',
+    'summary.global_quantities.h_98.value',
+    'summary.global_quantities.h_mode.value',
+    'summary.global_quantities.ip.value',
+    'summary.global_quantities.tau_energy.value',
+    'summary.global_quantities.v_loop.value',
+    'summary.local.separatrix.n_e.value',
+    'summary.local.separatrix.zeff.value',
+]
